@@ -3,9 +3,9 @@ n   <- length(yc); P   <- ppoints(n)
 qn  <- rep(0,n) 
 tol <- 0.001; maxit <- 20
 f.res <- .Fortran("qd2func",
-lambda=to.double(lambda),yc=to.double(yc),delta=to.single(delta),n=to.integer(n),mui=to.double(muI),
-sigmai=to.double(sigmaI),zero=to.double(zero),tol=to.double(tol),
-maxit=to.integer(maxit),p=to.double(P),qn=to.double(qn))
+lambda=as.double(lambda),yc=as.double(yc),delta=to.single(delta),n=to.integer(n),mui=as.double(muI),
+sigmai=as.double(sigmaI),zero=as.double(zero),tol=as.double(tol),
+maxit=to.integer(maxit),p=as.double(P),qn=as.double(qn))
 ql   <- qloggamma(P,lambda)
 z    <- lsfit(ql,f.res$qn)
 mu   <- as.numeric(z$coef[1])
